@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2025 OARC, Inc.
+ * Copyright (c) 2016-2026 OARC, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,6 +41,7 @@
 #include "tcpstate.h"
 #include "network.h"
 #include "dumper.h"
+#include "pcaps.h"
 
 #include <ldns/ldns.h>
 
@@ -124,10 +125,6 @@ size_t _get_pkthdr_caplen(void)
     return pkthdr_caplen;
 }
 
-#ifdef __linux__
-extern char* strptime(const char*, const char*, struct tm*);
-#endif
-
 time_t xtimegm(struct tm* tmp)
 {
 #if defined(__SVR4) && defined(__sun)
@@ -252,13 +249,6 @@ void check_gzip()
     if (dot) {
         wantgzip = (strcmp(dot, ".gz") == 0) ? TRUE : FALSE;
     }
-
-#if !(HAVE_GZOPEN && (HAVE_FUNOPEN || HAVE_FOPENCOOKIE))
-    if (wantgzip) {
-        fprintf(stderr, "error: gzip compression requested but not supported\n");
-        exit(1);
-    }
-#endif
 }
 
 int is_responder(iaddr ia)
@@ -637,6 +627,8 @@ void parse_args(int argc, char* argv[])
                 (*pl->extension)(DNSCAP_EXT_SET_OUTPUT_PKT, (set_output_pkt_t)set_output_pkt);
                 (*pl->extension)(DNSCAP_EXT_GET_PCAP_THREAD_FTELL, (get_pcap_thread_ftell_t)_get_pcap_thread_ftell);
                 (*pl->extension)(DNSCAP_EXT_GET_PKTHDR_CAPLEN, (get_pkthdr_caplen_t)_get_pkthdr_caplen);
+                (*pl->extension)(DNSCAP_EXT_BREAKLOOP_PCAPS, (breakloop_pcaps_t)breakloop_pcaps);
+                (*pl->extension)(DNSCAP_EXT_GET_LAST_TOTAL_COMPRESS_READ, (get_last_total_compress_read_t)get_last_total_compress_read);
             }
             snprintf(sn, sizeof(sn), "%s_getopt", pl->name);
             pl->getopt = dlsym(pl->handle, sn);
@@ -706,8 +698,10 @@ void parse_args(int argc, char* argv[])
             usage("unrecognized command line option");
         }
     }
-    assert(msg_wanted != 0U);
-    assert(err_wanted != 0U);
+    if (!msg_wanted)
+        usage("empty -m \"\" not allowed");
+    if (!err_wanted)
+        usage("empty -e \"\" not allowed");
     if (dump_type == nowhere && !preso && EMPTY(plugins))
         usage("without -w or -g, there would be no output");
     if (end_hide != 0U && wantfrags)
